@@ -24,6 +24,7 @@ use POSIX '_exit';
 use Sub::Mage;
 use URI::Split qw(uri_split uri_join);
 use Text::ParseWords 'quotewords';
+use Data::Dumper;
 
 # Enable Perl 6 knockoffs, and use 5.10.1, because smartmatching and other
 # things in 5.10 were changed in 5.10.1+.
@@ -336,21 +337,19 @@ sub no_mirror_download_dirlist {
     my $url = shift;
 
     my $dirlist;
-    given ($url) {
-        when (m!^ftp://.*$!) {
-            $dirlist = ftp_download_dirlist($url);
-        } when (m!^http://.*$!) {
-            $dirlist = http_download_dirlist($url);
-        } when (m!^file://.*$!) {
-          $dirlist = file_download_dirlist($url);
-        } default {
-            die <<EOD;
+    if ($url =~ m!^ftp://.*$!) {
+        $dirlist = ftp_download_dirlist($url);
+    } elsif ($url =~ m!^http://.*$!) {
+        $dirlist = http_download_dirlist($url);
+    } elsif ($url =~ m!^file://.*$!) {
+      $dirlist = file_download_dirlist($url);
+    } else {
+        die <<EOD;
 App-Fetchware: run-time syntax error: the url parameter your provided in
 your call to download_dirlist() [$url] does not have a supported URL scheme (the
 http:// or ftp:// part). The only supported download types, schemes, are FTP and
 HTTP. See perldoc App::Fetchware.
 EOD
-        }
     }
 
     return $dirlist;
@@ -691,21 +690,19 @@ sub no_mirror_download_file {
     my $url = shift;
 
     my $filename;
-    given ($url) {
-        when (m!^ftp://!) {
-            $filename = download_ftp_url($url);
-        } when (m!^http://!) {
-            $filename = download_http_url($url);
-        } when (m!^file://!) {
-            $filename = download_file_url($url);   
-        } default {
-            die <<EOD;
+    if ($url =~ m!^ftp://!) {
+        $filename = download_ftp_url($url);
+    } elsif ($url =~ m!^http://!) {
+        $filename = download_http_url($url);
+    } elsif ($url =~ m!^file://!) {
+        $filename = download_file_url($url);   
+    } else {
+        die <<EOD;
 App-Fetchware: run-time syntax error: the url parameter your provided in
 your call to download_file() [$url] does not have a supported URL scheme (the
 http:// or ftp:// part). The only supported download types, schemes, are FTP and
 HTTP. See perldoc App::Fetchware.
 EOD
-        }
     }
 
     return $filename;
@@ -932,12 +929,12 @@ EOD
     ###BUGALERT### What does this actually test?????
     if ($info->mode() & 022) { # Someone else can write this $fh.
         die <<EOD
-App-Fetchware-Util: The file fetchware attempted to open is writable by someone
-other than just the owner. Fetchwarefiles and fetchware packages must only be
-writable by the owner. Do not only change permissions to fix this error. This
-error may have allowed someone to alter the contents of your Fetchwarefile or
-fetchware packages. Ensure the file was not altered, then change permissions to
-644.
+App-Fetchware-Util: The file fetchware attempted to open [$file_to_check] is
+writable by someone other than just the owner. Fetchwarefiles and fetchware
+packages must only be writable by the owner. Do not only change permissions to
+fix this error. This error may have allowed someone to alter the contents of
+your Fetchwarefile or fetchware packages. Ensure the file was not altered, then
+change permissions to 644.
 EOD
     }
     
@@ -990,12 +987,14 @@ EOD
         if ($info->mode() & 022) { # Someone else can write this $fh...
             # ...except if this file has the sticky bit set and its a directory.
             die <<EOD unless $info->mode & 01000 and S_ISDIR($info->mode);
-App-Fetchware-Util: The file fetchware attempted to open is writable by someone
-other than just the owner. Fetchwarefiles and fetchware packages must only be
-writable by the owner. Do not only change permissions to fix this error. This
-error may have allowed someone to alter the contents of your Fetchwarefile or
-fetchware packages. Ensure the file was not altered, then change permissions to
-644.
+App-Fetchware-Util: The file fetchware attempted to open [$file_to_check] is
+writable by someone other than just the owner. Fetchwarefiles and fetchware
+packages must only be writable by the owner. Do not only change permissions to
+fix this error. This error may have allowed someone to alter the contents of
+your Fetchwarefile or fetchware packages. Ensure the file was not altered, then
+change permissions to 644. Permissions on failed directory were:
+@{[Dumper($info)]}
+Umask [@{[umask]}].
 EOD
         }
 
@@ -1143,47 +1142,19 @@ EOD
         
         # Code below based on a cool forking idiom by Aristotle.
         # (http://blogs.perl.org/users/aristotle/2012/10/concise-fork-idiom.html)
-        given ( scalar fork ) {
+        for ( scalar fork ) {
             # Fork failed.
-            when ( undef ) {
-                die <<EOD; 
+            # defined() operates on default variable, $_.
+            #if (not defined $_) {
+            if ($_ eq undef) {
+                die <<EOD;
 App-Fetchware-Util: Fork failed! This shouldn't happen!?! Os error [$!].
 EOD
-            # Fork succeeded, Child code goes here.
-            } when ( 0 ) {
-                close $readonly or die <<EOD;
-App-Fetchware-Util: Failed to close $readonly pipe in child. Os error [$!].
-EOD
-                # Drop privs.
-                # drop_privileges() dies on an error just let drop_privs() caller
-                # catch it.
-                my ($uid, $gid) = drop_privileges($regular_user); 
-
-
-                # Execute the coderef that is supposed to be done as non-root.
-                $child_code->($writeonly);
-
-                # Now close the pipe, to avoid creating a dead pipe causing a
-                # SIGPIPE to be sent to the parent.
-                close $writeonly or die <<EOD;
-App-Fetchware-Util: Failed to close $writeonly pipe in child. Os error [$!].
-EOD
-
-                # Exit success, because failure is only indicated by a thrown
-                # exception that bin/fetchware's main eval {} will catch, print,
-                # and exit non-zero indicating failure.
-                # Use POSIX's _exit() to avoid calling END{} blocks. This *must*
-                # be done to prevent File::Temp's END{} block from attempting to
-                # delete the temp directory that the parent still needs to
-                # finish installing or uninstalling. The parent's END{} block's
-                # will still be called, so this just turns off the child
-                # deleting the temp dir not the parent.
-                _exit 0;
-
-            # Fork succeeded, parent code goes here.
-            } default {
-                my $kidpid = $_;
+            }
 
+            # Fork succeeded, Parent code goes here.
+            my $kidpid = $_;
+            if ( $kidpid ) {
                 close $writeonly or die <<EOD;
 App-Fetchware-Util: Failed to close $writeonly pipe in parent. Os error [$!].
 EOD
@@ -1229,6 +1200,36 @@ EOD
                 } else {
                     return \$output;
                 }
+            # Fork succeeded, child code goes here.
+            } else {
+                close $readonly or die <<EOD;
+App-Fetchware-Util: Failed to close $readonly pipe in child. Os error [$!].
+EOD
+                # Drop privs.
+                # drop_privileges() dies on an error just let drop_privs() caller
+                # catch it.
+                my ($uid, $gid) = drop_privileges($regular_user); 
+
+
+                # Execute the coderef that is supposed to be done as non-root.
+                $child_code->($writeonly);
+
+                # Now close the pipe, to avoid creating a dead pipe causing a
+                # SIGPIPE to be sent to the parent.
+                close $writeonly or die <<EOD;
+App-Fetchware-Util: Failed to close $writeonly pipe in child. Os error [$!].
+EOD
+
+                # Exit success, because failure is only indicated by a thrown
+                # exception that bin/fetchware's main eval {} will catch, print,
+                # and exit non-zero indicating failure.
+                # Use POSIX's _exit() to avoid calling END{} blocks. This *must*
+                # be done to prevent File::Temp's END{} block from attempting to
+                # delete the temp directory that the parent still needs to
+                # finish installing or uninstalling. The parent's END{} block's
+                # will still be called, so this just turns off the child
+                # deleting the temp dir not the parent.
+                _exit 0;
             }
         }    
     # Non-Unix OSes just execute the $child_code.
@@ -1246,7 +1247,8 @@ EOD
 
 { # Bareblock just for the $MAGIC_NUMBER.
     # Determine $front_magic
-    my $front_magic = int(rand(8128389023));
+    my $front_magic;
+    $front_magic = int(rand(8128389023));
     # For no particular reason convert the random integer into hex, because I
     # never  store something in decimal and then exact same thing in hex.
     $front_magic = $front_magic . sprintf("%x", $front_magic);
@@ -1521,7 +1523,7 @@ App::Fetchware::Util - Miscelaneous functions for App::Fetchware.
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
